==> nextcloud-24.0.8.tgz: nextcloud/apps/dashboard/l10n/sl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna plošča",
    "Dashboard app" : "Program Nadzorna plošča",
    "Customize" : "Prilagodi",
    "Edit widgets" : "Izbor gradnikov",
    "Weather service" : "Vremenske storitve",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Za večjo zasebnost so podatki vremena pridobljeni prek strežnika Nextcloud, zato tretje osebe ne pridobijo nobenega vašega osebnega podatka.",
    "Weather data from Met.no" : "Podatke vremena omogoča Met.no",
    "geocoding with Nominatim" : "geokodiranje Nominatim",
    "elevation data from OpenTopoData" : "podatke nadmorske višine OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stanje",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dober dan",
    "Good afternoon, {name}" : "Dober dan, {name}",
    "Good evening" : "Dober večer",
    "Good evening, {name}" : "Dober večer, {name}",
    "Hello" : "Pozdravljeni",
    "Hello, {name}" : "Pozdravljeni, {name}",
    "Show something" : "Pokaži karkoli",
    "Change background image" : "Izbor slike ozadja",
    "Pick from Files" : "Izbor iz datotek",
    "Default images" : "Privzete slike",
    "Plain background" : "Enostavno ozadje",
    "Insert from {productName}" : "Vstavi iz {productName}"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-25.0.5.tgz: nextcloud/apps/dashboard/l10n/sl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna plošča",
    "Dashboard app" : "Program Nadzorna plošča",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Začnite dan s pravimi informacijami\n\nNadzorna plošča Nextcloud je prva točka dneva, ki vam omogoča\npregled prihajajočih sestankov, nujnih elektronskih sporočil in sporočil klepeta,\npodrobnosti o prejetih nalogah, najnovejših čivkih in še veliko več! Vsak uporabnik lahko doda gradnike\nin spreminja ozadje po svojih željah.",
    "Customize" : "Prilagodi",
    "Edit widgets" : "Izbor gradnikov",
    "Get more widgets from the App Store" : "Pridobi več gradnikov s spletišča App Store",
    "Weather service" : "Vremenske storitve",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Za večjo zasebnost so podatki vremena pridobljeni prek strežnika Nextcloud, zato tretje osebe ne pridobijo nobenega vašega osebnega podatka.",
    "Weather data from Met.no" : "Podatke vremena omogoča Met.no",
    "geocoding with Nominatim" : "geokodiranje Nominatim",
    "elevation data from OpenTopoData" : "podatke nadmorske višine OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stanje",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dober dan",
    "Good afternoon, {name}" : "Dober dan, {name}",
    "Good evening" : "Dober večer",
    "Good evening, {name}" : "Dober večer, {name}",
    "Hello" : "Pozdravljeni",
    "Hello, {name}" : "Pozdravljeni, {name}",
    "Change background image" : "Izbor slike ozadja",
    "Pick from Files" : "Izbor iz datotek",
    "Default images" : "Privzete slike",
    "Plain background" : "Enostavno ozadje",
    "Insert from {productName}" : "Vstavi iz {productName}"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
